package com.ruoyi.hezhi.service.impl;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.hezhi.domain.TbCourseEvaluate;
import com.ruoyi.hezhi.domain.dto.CourseEvaluateDTO;
import com.ruoyi.hezhi.mapper.TbCourseEvaluateMapper;
import com.ruoyi.hezhi.service.ITbCourseEvaluateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 课程评价Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-14
 */
@Service
public class TbCourseEvaluateServiceImpl implements ITbCourseEvaluateService
{
    @Autowired
    private TbCourseEvaluateMapper tbCourseEvaluateMapper;

    /**
     * 查询课程评价
     *
     * @param courseEvaluateId 课程评价主键
     * @return 课程评价
     */
    @Override
    public TbCourseEvaluate selectTbCourseEvaluateByCourseEvaluateId(Long courseEvaluateId)
    {
        return tbCourseEvaluateMapper.selectTbCourseEvaluateByCourseEvaluateId(courseEvaluateId);
    }

    /**
     * 查询课程评价列表
     *
     * @param tbCourseEvaluate 课程评价
     * @return 课程评价
     */
    @Override
    public List<TbCourseEvaluate> selectTbCourseEvaluateList(TbCourseEvaluate tbCourseEvaluate)
    {
        return tbCourseEvaluateMapper.selectTbCourseEvaluateList(tbCourseEvaluate);
    }

    /**
     * 新增课程评价
     *
     * @param tbCourseEvaluate 课程评价
     * @return 结果
     */
    @Override
    public int insertTbCourseEvaluate(TbCourseEvaluate tbCourseEvaluate)
    {
        tbCourseEvaluate.setCreateTime(DateUtils.getNowDate());
        return tbCourseEvaluateMapper.insertTbCourseEvaluate(tbCourseEvaluate);
    }

    /**
     * 修改课程评价
     *
     * @param tbCourseEvaluate 课程评价
     * @return 结果
     */
    @Override
    public int updateTbCourseEvaluate(TbCourseEvaluate tbCourseEvaluate)
    {
        tbCourseEvaluate.setUpdateTime(DateUtils.getNowDate());
        return tbCourseEvaluateMapper.updateTbCourseEvaluate(tbCourseEvaluate);
    }

    /**
     * 批量删除课程评价
     *
     * @param courseEvaluateIds 需要删除的课程评价主键
     * @return 结果
     */
    @Override
    public int deleteTbCourseEvaluateByCourseEvaluateIds(Long[] courseEvaluateIds)
    {
        return tbCourseEvaluateMapper.deleteTbCourseEvaluateByCourseEvaluateIds(courseEvaluateIds);
    }

    /**
     * 删除课程评价信息
     *
     * @param courseEvaluateId 课程评价主键
     * @return 结果
     */
    @Override
    public int deleteTbCourseEvaluateByCourseEvaluateId(Long courseEvaluateId)
    {
        return tbCourseEvaluateMapper.deleteTbCourseEvaluateByCourseEvaluateId(courseEvaluateId);
    }

    /**
     * 查询课程评价列表
     *
     * @param params 参数
     * @return ok
     */
    @Override
    public List<Map<String, Object>> getCourseEvaluateList(Map<String, Object> params) {
        return tbCourseEvaluateMapper.getCourseEvaluateList(params);
    }

    /**
     * 查询课程评价评分
     *
     * @param params 参数
     * @return ok
     */
    @Override
    public Map<String, Object> getCourseEvaluateScore(Map<String, Object> params) {
        return tbCourseEvaluateMapper.getCourseEvaluateScore(params);
    }

    /**
     * 提交评价
     *
     * @param courseEvaluateDTO
     * @return ok
     */
    @Override
    public AjaxResult submitEvaluation(CourseEvaluateDTO courseEvaluateDTO) {
        TbCourseEvaluate courseEvaluate = new TbCourseEvaluate();
        courseEvaluate.setCourseId(courseEvaluateDTO.getCourseId());
        courseEvaluate.setStudentName("学员_" + IdUtils.fastSimpleUUID().substring(1,8));
        courseEvaluate.setEvaluateStar(courseEvaluateDTO.getEvaluateStar());
        courseEvaluate.setEvaluateContent(courseEvaluateDTO.getEvaluateContent());
        courseEvaluate.setCreateTime(DateUtils.getNowDate());
        tbCourseEvaluateMapper.insertTbCourseEvaluate(courseEvaluate);
        return AjaxResult.success();
    }
}
